.. module:: pandas_indexing

========
Contents
========

.. toctree::
   :maxdepth: 2
   :caption: Documentation

   installation
   usage
   contributing

.. toctree::
   :maxdepth: 2
   :caption: API reference

   api

.. toctree::
   :maxdepth: 2
   :caption: Versions

   changelog
   AUTHORS

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
